
# Slot: target_type


Describes the neurodata_type of the target that the reference points to

URI: [nwb_schema_language:target_type](https://w3id.org/p2p_ld/nwb-schema-language/target_type)


## Domain and Range

None &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Link](Link.md)
 * [ReferenceDtype](ReferenceDtype.md)
